@@ -13,8 +13,7 @@
 # limitations under the License.
 
 from .memgraph import Memgraph  # noqa F401
-from .models import MemgraphConstraintExists, MemgraphConstraintUnique, Node, Relationship  # noqa F401
-from .query_builder import Match, InvalidMatchChainException, NoVariablesMatchedException  # noqa F401
-
+from .models import MemgraphConstraintExists, MemgraphConstraintUnique, Node, Path, Relationship  # noqa F401
+from .query_builder import InvalidMatchChainException, Match, NoVariablesMatchedException  # noqa F401
 
 __all__ = ["Memgraph"]
